Crate names_generator2

Crate names_generator2 

Functions

get_random
Generates a random name from the list of adjectives and animals in this crate formatted as “adjective-animal-{3-digit-random-number}”.