get_random

Function get_random 

pub fn get_random(rng: impl Rng) -> String
Generates a random name from the list of adjectives and animals in this crate formatted as “adjective-animal-{3-digit-random-number}”.